==> gitlab_16.11.6.orig.tar.bz2: gitlab-foss-v16.11.6/spec/support/shared_contexts/policies/group_policy_shared_context.rb <==
# frozen_string_literal: true

RSpec.shared_context 'GroupPolicy context' do
  let_it_be(:guest) { create(:user) }
  let_it_be(:reporter) { create(:user) }
  let_it_be(:developer) { create(:user) }
  let_it_be(:maintainer) { create(:user) }
  let_it_be(:owner) { create(:user) }
  let_it_be(:admin) { create(:admin, :without_default_org) }
  let_it_be(:non_group_member) { create(:user) }

  let_it_be(:organization) { create(:organization) }
  let_it_be(:organization_owner) { create(:organization_user, :owner, organization: organization).user }

  let_it_be(:group, refind: true) do
    create(:group, :private, :owner_subgroup_creation_only, organization: organization)
  end

  let(:public_permissions) do
    %i[
      read_group read_counts read_issue read_namespace
      read_label read_issue_board_list read_milestone read_issue_board
    ]
  end

  let(:guest_permissions) do
    %i[
      read_label read_group upload_file read_namespace_via_membership read_group_activity
      read_group_issues read_group_boards read_group_labels read_group_milestones
      read_group_merge_requests
    ]
  end

  let(:reporter_permissions) do
    %i[
      admin_label
      admin_milestone
      admin_issue_board
      read_container_image
      read_harbor_registry
      read_metrics_dashboard_annotation
      read_prometheus
      read_crm_contact
      read_crm_organization
      read_internal_note
      read_confidential_issues
    ]
  end

  let(:developer_permissions) do
    %i[
      admin_metrics_dashboard_annotation
      create_custom_emoji
      create_package
      read_cluster
    ]
  end

  let(:maintainer_permissions) do
    %i[
      destroy_package
      create_projects
      create_cluster update_cluster admin_cluster add_cluster
      destroy_upload
      admin_achievement
      award_achievement
      read_group_runners
    ]
  end

  let(:owner_permissions) do
    %i[
      owner_access
      admin_group
      admin_namespace
      admin_group_member
      admin_package
      change_visibility_level
      set_note_created_at
      create_subgroup
      read_statistics
      update_default_branch_protection
      register_group_runners
      read_billing
      edit_billing
      destroy_issue
      admin_member_access_request
      update_git_access_protocol
      remove_group
      view_edit_page
    ]
  end

  let(:admin_permissions) { %i[read_confidential_issues read_internal_note] }

  before_all do
    group.add_guest(guest)
    group.add_reporter(reporter)
    group.add_developer(developer)
    group.add_maintainer(maintainer)
    group.add_owner(owner)
  end

  subject { described_class.new(current_user, group) }
end

==> gitlab_17.0.8.orig.tar.bz2: gitlab-foss-v17.0.8/spec/support/shared_contexts/policies/group_policy_shared_context.rb <==
# frozen_string_literal: true

RSpec.shared_context 'GroupPolicy context' do
  let_it_be(:organization) { create(:organization) }
  let_it_be(:group, refind: true) do
    create(:group, :private, :owner_subgroup_creation_only, :allow_runner_registration_token,
      organization: organization)
  end

  let_it_be(:guest) { create(:user, guest_of: group) }
  let_it_be(:reporter) { create(:user, reporter_of: group) }
  let_it_be(:developer) { create(:user, developer_of: group) }
  let_it_be(:maintainer) { create(:user, maintainer_of: group) }
  let_it_be(:owner) { create(:user, owner_of: group) }
  let_it_be(:admin) { create(:admin, :without_default_org) }
  let_it_be(:non_group_member) { create(:user) }

  let_it_be(:organization_owner) { create(:organization_user, :owner, organization: organization).user }

  let(:public_permissions) do
    %i[
      read_group read_counts read_issue read_namespace
      read_label read_issue_board_list read_milestone read_issue_board
    ]
  end

  let(:guest_permissions) do
    %i[
      read_label read_group upload_file read_namespace_via_membership read_group_activity
      read_group_issues read_group_boards read_group_labels read_group_milestones
      read_group_merge_requests
    ]
  end

  let(:reporter_permissions) do
    %i[
      admin_label
      admin_milestone
      admin_issue_board
      read_container_image
      read_harbor_registry
      read_metrics_dashboard_annotation
      read_prometheus
      read_crm_contact
      read_crm_organization
      read_internal_note
      read_confidential_issues
    ]
  end

  let(:developer_permissions) do
    %i[
      admin_metrics_dashboard_annotation
      create_custom_emoji
      create_package
      read_cluster
    ]
  end

  let(:maintainer_permissions) do
    %i[
      destroy_package
      create_projects
      create_cluster update_cluster admin_cluster add_cluster
      destroy_upload
      admin_achievement
      award_achievement
      read_group_runners
    ]
  end

  let(:owner_permissions) do
    %i[
      owner_access
      admin_group
      admin_namespace
      admin_group_member
      admin_package
      change_visibility_level
      set_note_created_at
      create_subgroup
      read_statistics
      update_default_branch_protection
      register_group_runners
      read_billing
      edit_billing
      destroy_issue
      admin_member_access_request
      update_git_access_protocol
      remove_group
      view_edit_page
    ]
  end

  let(:admin_permissions) { %i[read_confidential_issues read_internal_note] }

  subject { described_class.new(current_user, group) }
end
